-- Create a simple window for status. In the "Update" event handler, Read the defaults, Output the saved data files. unload the plugin 
-- we can't guarantee that the data is flushed to disk until we unload so we use another plugin, MoorMapTerminator to terminate
-- this plugin AFTER the data is processed and saved. The main app will detect MoorMapTerminator and will in turn terminate that.

-- the annotations should be moved to the MapData_x files so that all map specific data is in one place
-- but for now, it's kind of convenient for them to be here

import "GaranStuff.MoorMap.Class";
import "GaranStuff.MoorMap.VindarPatch";
import "GaranStuff.MoorMap.Strings";
import "GaranStuff.MoorMap.Table";

import "Turbine";
import "Turbine.UI";
import "Turbine.UI.Lotro";

language=1;

-- all annotations have the form:{MapID, N/S, E/W, IconID, Allegiance, TextID, Description, NPCRank/MapID/Tier, NPC Type, QuestType, SpecialLoot}
-- Annotation Type follows the Map Filter types plus the Creep specific "Map In"
-- TextID is only valid for the defaults and will allow using the appropriately translated text value from Resource
-- IconID:
-- 1=uncontestable home base (Grams, GV)
-- 2=fixed control, attackable base (Ost, DG)
-- 3=contestable base (LC, TR, TA, Isen, LC)
-- 4=contestable outpost (ROP,POP,SOP,AE,IsenOP)
-- 5=point of interest (STAB, WTAB, Grothum, HH, DC)
-- 6=minor fortification (EC,OC)
-- 7=Rez Circle
-- 8=Crude Map in
-- 9=Poor Map in
-- 10=Good Map in
-- 11=NPC
-- 12=Freep Map in
-- 14=Autioneer
-- 15=Barber
-- 16=Bard
-- 17=Camp Site 0x410d4636 (15x15), 0x410d4635 (30x30)/highlight 0x410d4637 (30x30)
-- 18=Crafting Facility
-- 19=Crafting Resource (not sure I want to include these...)
-- 20=Crafting Vendor
-- 21=Faction Representative
-- 22=Fellow (not available without Lua map info)
-- 23=Fellowship Leader (not available without Lua map info)
-- 24=Fellowship Shared Tracking (not available without Lua map info)
-- 25=Item-Master
-- 26=Mailbox 0x41007f7a (18x18)
-- 27=Milestone
-- 28=Pet (not available without Lua map info)
-- 29=Quest NPC/location/item
-- 30=Quest Escort (not available without Lua map info)
-- 31=Quest Failer (not available without Lua map info)
-- 32=Reflecting Pool
-- 33=Settlement
-- 34=Stable-master
-- 35=Town Crier
-- 36=Tracked Target (not available without Lua map info)
-- 37=Trader 0x410d465a (16x16) 0x410d465c (30x30)/highlight 0x410d465d
-- 38=Trainer
-- 39=Vault-keeper
-- 40=Vendor
-- 41=Map connector 0x410081a2 (63x63)
-- 42=Skirmish Camp
-- 43= Ore Node
-- 44= Wood Node
-- 45= Scholar Node
-- 46= Cook Ingredient
-- 47= Muster Horn
-- 48= Scholar Ingredient

-- Allegiance:
-- 1=Contestable
-- 2=Creep
-- 3=Freep
-- 4=Delving

-- NPC Rank(for type=11)/MapID(for type=13)/Tier (for type=43,44,45):
-- 0=undefined/not an npc
-- 1=generic
-- 2=Tyrant
-- 3=Taskmaster
-- 4=Chieftain
-- 5=Soldier
-- 6=CG
-- 7=First Marshal
-- 8=Lietenant
-- 9=Sergeant-at-Arms

-- NPC Type
-- nil/0=generic (or not an NPC)
-- 1=Corrupter/Bard
-- 2=Trainer
-- 3=Barter
-- 4=Merchant
-- 5=Stablemaster
-- 6=Tyrant/Commander
-- 7=Named Quest Mob/Ally
-- 

-- Quest Type: (note, this is a bit mask so more than one may apply)
-- 0=not quest granter
-- 1=Creep generic
-- 2=Creep Grams Map Credit
-- 4=Creep Lugz Map Credit
-- 8=Creep Isen Map Credit
-- 16=Creep TA Map Credit
-- 32=Creep TR Map Credit
-- 64=Creep LC Map Credit
-- 128=Freep generic

-- Special Drops (note, this is a bit mask so more than one may apply) beryl ruby saphire adamant
-- 0=none
-- 1=Ruby Shard
-- 2=Saphire Shard
-- 4=Adamant Shard
-- 8=Beryl Shard
-- 16= Mithril Flake
-- 32= Symbol of Celebrimbor (not sure this is worth tracking since they drop mostly from instance chests now)
-- 64=.. whatever the lvl 65 first age crafting item will be
-- 128=..spare


-- mapInfo is in the form {Index,StringResourceID, ImageResourceID/Path, Width, Height, HFactor,HOffset,WFactor,WOffset,ParentMapID,MapType,Region,MaxNS,MinEW,MinNS,MaxEW,Tier}
-- HFactor and HOffset are used in the conversion from map coordinates to pixels: X=Height*HFactor+HOffset will convert coordinate "Height" to pixel "X"
-- ParentMapID is used to create the tree structure
-- MapTypeID - 0=Undefined, 1=Parchment, 2=Interior/Underground, 3=Interior/Underground subzone (hidden until parent is moused over in list)
-- Region is the region code (from /loc) 0=Undefined/world map, 1=Eriador, 2=Rhovanion
-- Min&Max coordinates are the corners of the map
-- Tier is the zoom level of the map with "Middle Earth" being 1, "Eriador" and "Rhovanion" being 2, etc. this is used to determine the best map for adding annotations whose coordinates are included in more than one map
-- iconInfo is in the form {StringResourceID, Height, Width, Image ResourceID/Path, Highlighted Image ResourceID/Path}

worldNames={}
worldNames[1]="Arkenstone";
worldNames[2]="Brandywine";
worldNames[3]="Crickhollow";
worldNames[4]="Dwarrowdelf";
worldNames[5]="Elendilmir";
worldNames[6]="Firefoot";
worldNames[7]="Gladden";
worldNames[8]="Imladris";
worldNames[9]="Landroval";
worldNames[10]="Meneldor";
worldNames[11]="Nimrodel";
worldNames[12]="Riddermark";
worldNames[13]="Silverlode";
worldNames[14]="Vilya";
worldNames[15]="Windfola";
worldNames[16]="_DE_Anduin";
worldNames[17]="_DE_Gwaihir";
worldNames[18]="_DE_Maiar";
worldNames[19]="_DE_Morthond";
worldNames[20]="_DE_Vanyar";
worldNames[21]="_DE_RP_Belegaer";
worldNames[22]="_EN_Eldar";
worldNames[23]="_EN_Evernight";
worldNames[24]="_EN_Gilrain";
worldNames[25]="_EN_Snowbourn";
worldNames[26]="_EN_Withywindle";
worldNames[27]="_EN_RP_Laurelin";
worldNames[28]="_FR_Sirannon";
worldNames[29]="_FR_RP_Estel";


StatusDisplay=class(Turbine.UI.Lotro.Window);

function StatusDisplay:Constructor()
	Turbine.UI.Lotro.Window.Constructor(self);
	self:SetSize(400,100);
	self:SetPosition((Turbine.UI.Display:GetWidth() - self:GetWidth())/2,(Turbine.UI.Display:GetHeight() - self:GetHeight())/2)
	self:SetZOrder(self:GetZOrder()+1); -- pop us in front
	self:SetText("MoorMap Defaults");
	self.Status="Loading";
	self.StatusText=Turbine.UI.Label();
	self.StatusText:SetParent(self);
	self.StatusText:SetSize(200,18);
	self.StatusText:SetPosition((self:GetWidth()-self.StatusText:GetWidth())/2,40);
	self.StatusText:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
	self.StatusText:SetText(self.Status);

	self.MapText=Turbine.UI.Label();
	self.MapText:SetParent(self);
	self.MapText:SetSize(200,18);
	self.MapText:SetPosition((self:GetWidth()-self.MapText:GetWidth())/2,60);
	self.MapText:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);

	self:SetWantsUpdates(true);
	self.MapIndex=1;
	self.WorldIndex=0;

	-- retrieve the "language" setting that was last saved (default is English if it was never saved)
	local tmpSettings=PatchDataLoad(Turbine.DataScope.Account, "MoorMapSettings");
	local index;
	if (tmpSettings~=nil) then
		if tostring(type(tmpSettings))=="table" then
			for index=1,#tmpSettings do
				if tostring(type(tmpSettings[index]))=="table" then
					if (tmpSettings[index][1]=="language") then
						if tonumber(tmpSettings[index][2])~=nil then
							language=tonumber(tmpSettings[index][2]);
						end
					end
				end
			end
		end
	end

	self.Update=function()
		if (Plugins["MoorMapDefaults"] ~= nil) and self.Status=="Loading" then
			self.Status="Initializing";
			Plugins["MoorMapDefaults"].Unload = function(self,sender,args)
				Turbine.PluginManager.UnloadScriptState("MoorMapTerminator"); -- terminate the script that terminates us. how touching :)
			end
		elseif self.Status=="Initializing" then
			self.Status="Processing"
		elseif self.Status=="Processing" then
			if self.MapIndex==1 then
				if self.WorldIndex==0 then
					-- process the generic "Ettenmoors" data -- this MUST be processed first since the world specific string indexes depend on this
					self.MapText:SetText(Resource[language][mapInfo[self.MapIndex][2]]);
					ProcessMap();
					self.WorldIndex=1;
				elseif self.WorldIndex<#worldNames then
					-- process the world specific Ettenmoors data
					self.MapText:SetText("Ettenmoors:"..worldNames[self.WorldIndex]);
					ProcessMap(worldNames[self.WorldIndex]);
					self.WorldIndex=self.WorldIndex+1;
				else
					-- allow processing to fall through to other maps
					self.MapIndex=2;
				end
			else
				if self.MapIndex>#mapInfo then
					self.Status="Terminating"
				else
					self.MapText:SetText(Resource[language][mapInfo[self.MapIndex][2]]);
					ProcessMap();
					self.MapIndex=self.MapIndex+1
				end
			end
		elseif self.Status=="Terminating" then
			self:SetWantsUpdates(false);
			Turbine.PluginManager.LoadPlugin("MoorMapTerminator");
		end		
		self.StatusText:SetText(self.Status);
	end
end


function LoadDefaults()
	local tmpIconInfo={};
	local tmpMapInfo={};
	tmpIconInfo[1]={106,36,36,"GaranStuff/MoorMap/Resources/MainBase.tga","GaranStuff/MoorMap/Resources/MainBase_hover.tga","GaranStuff/MoorMap/Resources/MainBase_icon.tga"};
	tmpIconInfo[2]={107,32,32,"GaranStuff/MoorMap/Resources/Base.tga","GaranStuff/MoorMap/Resources/Base_hover.tga","GaranStuff/MoorMap/Resources/Base_icon.tga"};
	tmpIconInfo[3]={108,24,24,"GaranStuff/MoorMap/Resources/Fort.tga","GaranStuff/MoorMap/Resources/Fort_hover.tga","GaranStuff/MoorMap/Resources/Fort_icon.tga"};
	tmpIconInfo[4]={109,24,24,"GaranStuff/MoorMap/Resources/Outpost.tga","GaranStuff/MoorMap/Resources/Outpost_hover.tga","GaranStuff/MoorMap/Resources/Outpost_icon.tga"};
	tmpIconInfo[5]={110,24,24,"GaranStuff/MoorMap/Resources/POI.tga","GaranStuff/MoorMap/Resources/POI_hover.tga","GaranStuff/MoorMap/Resources/POI_icon.tga"};
	tmpIconInfo[6]={111,18,18,"GaranStuff/MoorMap/Resources/Stockade.tga","GaranStuff/MoorMap/Resources/Stockade_hover.tga","GaranStuff/MoorMap/Resources/Stockade_icon.tga"};
	tmpIconInfo[7]={112,24,24,"GaranStuff/MoorMap/Resources/Rez.tga","GaranStuff/MoorMap/Resources/Rez_hover.tga","GaranStuff/MoorMap/Resources/Rez_icon.tga"};
	tmpIconInfo[8]={113,18,18,"GaranStuff/MoorMap/Resources/CrudeMap.tga","GaranStuff/MoorMap/Resources/CrudeMap_hover.tga","GaranStuff/MoorMap/Resources/CrudeMap.tga"};
	tmpIconInfo[9]={114,18,18,"GaranStuff/MoorMap/Resources/PoorMap.tga","GaranStuff/MoorMap/Resources/PoorMap_hover.tga","GaranStuff/MoorMap/Resources/PoorMap.tga"};
	tmpIconInfo[10]={115,18,18,"GaranStuff/MoorMap/Resources/GoodMap.tga","GaranStuff/MoorMap/Resources/GoodMap_hover.tga","GaranStuff/MoorMap/Resources/GoodMap.tga"};
	tmpIconInfo[11]={116,16,16,"GaranStuff/MoorMap/Resources/NPC.tga","GaranStuff/MoorMap/Resources/NPC_hover.tga","GaranStuff/MoorMap/Resources/NPC.tga"};
	tmpIconInfo[12]={117,18,18,"GaranStuff/MoorMap/Resources/FreepMap.tga","GaranStuff/MoorMap/Resources/FreepMap_hover.tga","GaranStuff/MoorMap/Resources/FreepMap.tga"};
	tmpIconInfo[13]={118,18,18,"GaranStuff/MoorMap/Resources/UnearnedMap.tga","GaranStuff/MoorMap/Resources/UnearnedMap_hover.tga","GaranStuff/MoorMap/Resources/UnearnedMap.tga"};
	tmpIconInfo[14]={120,32,32,"GaranStuff/MoorMap/Resources/Auctioneer.tga","GaranStuff/MoorMap/Resources/Auctioneer_hover.tga","GaranStuff/MoorMap/Resources/Auctioneer_icon.tga"};
	tmpIconInfo[15]={121,32,32,"GaranStuff/MoorMap/Resources/Barber.tga","GaranStuff/MoorMap/Resources/Barber_hover.tga","GaranStuff/MoorMap/Resources/Barber_icon.tga"};
	tmpIconInfo[16]={122,32,32,"GaranStuff/MoorMap/Resources/Bard.tga","GaranStuff/MoorMap/Resources/Bard_hover.tga","GaranStuff/MoorMap/Resources/Bard_icon.tga"};
	tmpIconInfo[17]={123,30,30,0x410d4635,0x410d4637,0x410d4636}; -- Camp Site (mini=0x410d4636 (15x15))
	tmpIconInfo[18]={124,30,30,"GaranStuff/MoorMap/Resources/CraftSite.tga","GaranStuff/MoorMap/Resources/CraftSite_hover.tga","GaranStuff/MoorMap/Resources/CraftSite_icon.tga"}; -- Craft Facility
	tmpIconInfo[19]={125,0,0,"GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga"}; -- ResourceNode
	tmpIconInfo[20]={126,32,32,"GaranStuff/MoorMap/Resources/CraftVendor.tga","GaranStuff/MoorMap/Resources/CraftVendor_hover.tga","GaranStuff/MoorMap/Resources/CraftVendor_icon.tga"};
	tmpIconInfo[21]={127,32,32,"GaranStuff/MoorMap/Resources/FactionRep.tga","GaranStuff/MoorMap/Resources/FactionRep_hover.tga","GaranStuff/MoorMap/Resources/FactionRep_icon.tga"};
	tmpIconInfo[22]={128,0,0,"GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga"}; -- Fellow
	tmpIconInfo[23]={129,0,0,"GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga"}; -- FellowLeader
	tmpIconInfo[24]={130,0,0,"GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga"}; -- FellowTrack
	tmpIconInfo[25]={131,32,32,"GaranStuff/MoorMap/Resources/Item-master.tga","GaranStuff/MoorMap/Resources/Item-master_hover.tga","GaranStuff/MoorMap/Resources/Item-master_icon.tga"};
	tmpIconInfo[26]={132,32,32,"GaranStuff/MoorMap/Resources/Mailbox.tga","GaranStuff/MoorMap/Resources/Mailbox_hover.tga",0x41007f7a};--Mailbox mini = 0x41007f7a (18x18)
	tmpIconInfo[27]={133,32,32,"GaranStuff/MoorMap/Resources/Milestone.tga","GaranStuff/MoorMap/Resources/Milestone_hover.tga","GaranStuff/MoorMap/Resources/Milestone_icon.tga"};
	tmpIconInfo[28]={134,0,0,"GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga"}; -- Pet
	tmpIconInfo[29]={135,0,0,"GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga"}; -- Quest NPC
	tmpIconInfo[30]={136,0,0,"GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga"}; -- Quest Escort
	tmpIconInfo[31]={137,0,0,"GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga"}; -- Quest Failer
	tmpIconInfo[32]={138,32,32,"GaranStuff/MoorMap/Resources/ReflectingPool.tga","GaranStuff/MoorMap/Resources/ReflectingPool_hover.tga","GaranStuff/MoorMap/Resources/ReflectingPool_icon.tga"};
	tmpIconInfo[33]={139,32,32,"GaranStuff/MoorMap/Resources/Settlement.tga","GaranStuff/MoorMap/Resources/Settlement_hover.tga","GaranStuff/MoorMap/Resources/Settlement_icon.tga"}; -- Settlement
	tmpIconInfo[34]={140,32,32,"GaranStuff/MoorMap/Resources/Stablemaster.tga","GaranStuff/MoorMap/Resources/Stablemaster_hover.tga","GaranStuff/MoorMap/Resources/Stablemaster_icon.tga"};
	tmpIconInfo[35]={141,32,32,"GaranStuff/MoorMap/Resources/TownCrier.tga","GaranStuff/MoorMap/Resources/TownCrier_hover.tga","GaranStuff/MoorMap/Resources/TownCrier_icon.tga"};
	tmpIconInfo[36]={142,0,0,"GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga"}; -- Tracked Target
	tmpIconInfo[37]={143,30,30,0x410d465c,0x410d465d,0x410d465a}; -- Trader mini=0x410d465a (16x16)
	tmpIconInfo[38]={144,32,32,"GaranStuff/MoorMap/Resources/Trainer.tga","GaranStuff/MoorMap/Resources/Trainer_hover.tga","GaranStuff/MoorMap/Resources/Trainer_icon.tga"};
	tmpIconInfo[39]={145,32,32,"GaranStuff/MoorMap/Resources/VaultKeeper.tga","GaranStuff/MoorMap/Resources/VaultKeeper_hover.tga","GaranStuff/MoorMap/Resources/VaultKeeper_icon.tga"};
	tmpIconInfo[40]={146,32,32,"GaranStuff/MoorMap/Resources/Vendor.tga","GaranStuff/MoorMap/Resources/Vendor_hover.tga","GaranStuff/MoorMap/Resources/Vendor_icon.tga"};
	tmpIconInfo[41]={147,63,63,"GaranStuff/MoorMap/Resources/MapConnector_blank.tga",0x410081a2,0x410081a2};
	tmpIconInfo[42]={154,32,32,"GaranStuff/MoorMap/Resources/SkirmishCamp.tga","GaranStuff/MoorMap/Resources/SkirmishCamp_hover.tga","GaranStuff/MoorMap/Resources/SkirmishCamp_icon.tga"};
	tmpIconInfo[43]={155,24,24,"GaranStuff/MoorMap/Resources/OreNode.tga","GaranStuff/MoorMap/Resources/OreNode_hover.tga","GaranStuff/MoorMap/Resources/OreNode_icon.tga"};
	tmpIconInfo[44]={156,24,24,"GaranStuff/MoorMap/Resources/WoodNode.tga","GaranStuff/MoorMap/Resources/WoodNode_hover.tga","GaranStuff/MoorMap/Resources/WoodNode_icon.tga"};
	tmpIconInfo[45]={157,24,24,"GaranStuff/MoorMap/Resources/ScholarNode.tga","GaranStuff/MoorMap/Resources/ScholarNode_hover.tga","GaranStuff/MoorMap/Resources/ScholarNode_icon.tga"};
	tmpIconInfo[46]={162,24,24,"GaranStuff/MoorMap/Resources/Cook.tga","GaranStuff/MoorMap/Resources/Cook_hover.tga","GaranStuff/MoorMap/Resources/Cook_icon.tga"};
	tmpIconInfo[47]={163,32,32,"GaranStuff/MoorMap/Resources/MusterHorn.tga","GaranStuff/MoorMap/Resources/MusterHorn_hover.tga","GaranStuff/MoorMap/Resources/MusterHorn_icon.tga"};
	tmpIconInfo[48]={182,24,24,"GaranStuff/MoorMap/Resources/Scholar.tga","GaranStuff/MoorMap/Resources/Scholar_hover.tga","GaranStuff/MoorMap/Resources/Scholar_icon.tga"};
	tmpIconInfo[49]={183,32,32,"GaranStuff/MoorMap/Resources/Dungeon.tga","GaranStuff/MoorMap/Resources/Dungeon_hover.tga","GaranStuff/MoorMap/Resources/Dungeon_icon.tga"};

	-- Map Data
	tmpMapInfo[1]={1,19,tonumber("0x41008133"),1024,768,63.6,1541,-63.5,-630,3,1,1,-10,-24.3,-22,-8.2,3}; -- ettenmoors
	tmpMapInfo[2]={2,20,tonumber(0x41008139),1024,768, 1, 0, 1, 0,0,1,0,0,0,0,0,1}; -- Middle Earth coordinates are meaningless on this map :( different systems are in use in Eriador and Rhovanion CONNECTIONS DONE
	tmpMapInfo[3]={3,21,tonumber(0x41008138),1024,768,6.5,951,-6.5,186,2,1,1,28.6,-146.4,-89.4,11.1,2}; -- Eriador
	tmpMapInfo[4]={4,22,tonumber(0x41008131),1024,768,35.03,1498,-34.95,514,3,1,1,14.7,-42.8,-7.3,-13.6,3}; -- Angmar
	tmpMapInfo[5]={5,23,tonumber(0x41008136),1024,768,36.27,2377,-36.18,-640,3,1,1,-17.7,-65.6,-38.9,-37.4,3}; -- Bree-land
	tmpMapInfo[6]={6,24,tonumber(0x41008135),1024,768,182.68,9280,-182.62,-4414,5,1,1,-24.2,-50.8,-28.4,-45.2,4}; -- Archet
	tmpMapInfo[7]={7,25,tonumber(0x4110a841),1024,768,213.13,12203,-213.06,-6370,5,1,1,-29.9,-57.3,-33.5,-52.5,4}; -- Barrow Downs North
	tmpMapInfo[8]={8,26,tonumber(0x4110a842),1024,768,173.38,10012,-174.32,-5700,5,1,1,-32.7,-57.8,-37.1,-51.9,4}; -- Barrow Downs South
	tmpMapInfo[9]={9,27,tonumber(0x41008134),1024,768,150,8180,-150,-4210,5,1,1,-28.1,-54.6,-33.2,-47.8,4}; -- Bree
	tmpMapInfo[10]={10,28,tonumber(0x410d9a54),1024,768,189.44,9468,-191.75,-6519,5,1,1,-34,-50,-38,-44.6,4}; -- Bree-land Homesteads
	tmpMapInfo[11]={11,29,tonumber(0x410e4ddd),1024,768,79.90,5206,-79.90,-2332,5,1,1,-29.2,-65.2,-38.8,-52.4,4}; -- The Old Forest
	tmpMapInfo[12]={12,30,tonumber(0x411041a4),1024,768,32.99,1041,-32.92,-1767,3,1,1,-53.7,-31.6,-77,-.6,3}; -- Enedwaith
	tmpMapInfo[13]={13,31,tonumber(0x4100812c),1024,768,38.7,4371,-38.66,-484,3,1,1,-12.6,-113,-32.4,-86.6,3}; -- Ered Luin
	tmpMapInfo[14]={14,32,tonumber(0x410d9934),1024,768,182.78,17099,-182.72,-4437,13,1,1,-24.3,-93.6,-28.5,-88,4}; -- Falathlorn Homesteads
	tmpMapInfo[15]={15,33,tonumber(0x4100812b),1024,768,128.70,13735,-128.75,-1442,13,1,1,-11.2,-106.8,-17.2,-98.8,4}; -- Thorin's Gate
	tmpMapInfo[16]={16,34,tonumber(0x410d9a56),1024,768,192.45,21143,-192.65,-2531,13,1,1,-13.2,-109.9,-17.2,-104.6,4}; -- Thorin's Hall Homesteads
	tmpMapInfo[17]={17,35,tonumber(0x410e8686),1024,768,33.8,802,-33.75,-1188,3,1,1,-35.2,-23.8,-58,6.5,3}; -- Eregion
	tmpMapInfo[18]={18,36,tonumber(0x410e8694),1024,768,138.8,1237,-139.5,-6765,17,1,1,-48.5,-9,-54,-1.6,4}; -- The Walls of Moria
	tmpMapInfo[19]={19,37,tonumber(0x4101f084),1024,768,33.7,2783,-33.71,-53,3,1,1,-1.6,-82.6,-24.4,-52.3,3}; -- Evendim
	tmpMapInfo[20]={20,38,tonumber(0x410E6EAD),1024,768,134.61,9890,-134.56,-2085,19,1,1,-15.5,-73.5,-21.2,-65.9,4}; -- Annuminas
	tmpMapInfo[21]={21,39,tonumber(0x410e3f46),1024,768,25.02,2320,-25.07,625,3,1,1,24.9,-92.8,-5.7,-51.9,3}; -- Forochel
	tmpMapInfo[22]={22,40,tonumber(0x4110d5a5),1024,768,213.13,20545,-213.06,3069,3,1,1,14.4,-96.4,10.8,-91.6,3}; -- Frostbluff
	tmpMapInfo[23]={23,41,tonumber(0x41008130),1024,768,43.72,1935,-43.83,-1148,3,1,1,-26.2,-44.3,-43.7,-20.9,3}; -- Lone-lands
	tmpMapInfo[24]={24,42,tonumber(0x4100812f),1024,768,41.30,489,-41.24,-602,3,1,1,-14.6,-11.9,-33.2,12.9,3}; -- Misty Mountains
	tmpMapInfo[25]={25,43,tonumber(0x41008132),1024,768,36.28,2190,-36.18,-47,3,1,1,-1.3,-60.4,-22.5,-32.2,3}; -- North Downs
	tmpMapInfo[26]={26,44,tonumber(0x41008137),1024,768,48.48,3921,-48.24,-1104,3,1,1,-22.9,-80.9,-38.8,-59.8,3}; -- The Shire
	tmpMapInfo[27]={27,45,tonumber(0x410d9a57),1024,768,182.68,14130,-178.37,-6171,26,1,1,-34.6,-77.4,-38.9,-71.8,4}; -- Shire Homesteads
	tmpMapInfo[28]={28,46,tonumber(0x4100812e),1024,768,37.61,988,-37.41,-778,3,1,1,-20.8,-26.3,-41.3,.9,3}; -- Trollshaws
	tmpMapInfo[29]={29,47,tonumber(0x4100812d),1024,768,105.46,982,-106.53,-2801,28,1,1,-26.3,-9.4,-33.5,.3,4}; -- Rivendell
	tmpMapInfo[30]={30,48,tonumber(0x410e868b),1024,768,5.98,876,-5.93,252,2,1,2,42.4,-146.5,-86.9,24.6,2}; -- Rhovanion
	tmpMapInfo[31]={31,49,tonumber(0x410e8707),1024,768,48.7,3990,-48.63,-223,30,1,2,-4.6,-82,-20.4,-61,3}; -- Lothlrien
	tmpMapInfo[32]={32,50,tonumber(0x410e8706),1024,768,179.47,12554,-178.37,-2300,31,1,2,-12.9,-70,-17.2,-64.3,4}; -- Caras Galadhon
	tmpMapInfo[33]={33,51,tonumber(0x41100DF2),1024,768,41.2,2618,-41.2,-200,30,1,2,-4.9,-63.6,-23.5,-38.8,3}; -- mirkwood
	tmpMapInfo[34]={34,52,tonumber(0x410e8708),1024,768,30,3653,-29.9,86,30,1,2,2.8,-121.8,-22.8,-87.7,3}; -- moria
	tmpMapInfo[35]={35,53,tonumber(0x410e871d),1024,768,63.94,7289,-63.92,128,34,1,2,2,-114,-10,-98,4}; -- Durin's Way
	tmpMapInfo[36]={36,54,tonumber(0x410e8716),1024,768,136.4,15286,-136.96,-1698,34,1,2,-12.4,-112.1,-18,-104.6,4}; -- Flaming Deeps
	tmpMapInfo[37]={37,55,tonumber(0x410e8715),1024,768,132.86,13658,-132.24,-1401,34,1,2,-10.6,-102.8,-16.4,-95.1,4}; -- Foundations of Stone
	tmpMapInfo[38]={38,56,tonumber(0x410e871a),1024,768,91.4,9612,-91.4,-365,34,1,2,-4,-105.2,-12.4,-94,4}; -- Nud Melek
	tmpMapInfo[39]={39,57,tonumber(0x410e8718),1024,768,106.56,11632,-108.03,-1004,34,1,2,-9.3,-109.2,-16.4,-99.6,4}; -- Redhorn Lodes
	tmpMapInfo[40]={40,58,tonumber(0x410e8e5a),1024,768,162.38,22967,-163.19,12060,34,1,2,73.9,-141.5,69.2,-135.2,4}; -- The Grand Stair
	tmpMapInfo[41]={41,59,tonumber(0x410e871c),1024,768,141.8,16611,-141.8,-690,34,1,2,-4.9,-117.2,-10.3,-110,4}; -- The Great Delving
	tmpMapInfo[42]={42,60,tonumber(0x410e8719),1024,768,142.08,16486,-142.04,-1221,34,1,2,-8.6,-116.1,-14,-108.9,4}; -- The Silvertine Lodes
	tmpMapInfo[43]={43,61,tonumber(0x410e8717),1024,768,73.60,8865,-73.75,-914,34,1,2,-12.4,-120.5,-22.8,-106.6,4}; -- The Waterworks
	tmpMapInfo[44]={44,62,tonumber(0x410e871b),1024,768,76.34,8700,-75.94,-296,34,1,2,-3.9,-114,-14,-100.6,4}; -- Zelem Melek
	tmpMapInfo[45]={45,63,tonumber(0x410e871e),1024,768,134.61,15209,-134.56,2328,34,1,2,17.3,-113,11.6,-105.4,4}; -- Zirak Zigil
-- these are the first "interior maps"
	tmpMapInfo[46]={46,184,tonumber(0x41005d2f),1600,1200,281.25,-12557,-292.53,22988,15,2,1,17.3,-113,11.6,-105.4,5}; -- Thorin's Hall main floor
	tmpMapInfo[47]={47,185,tonumber(0x410d4163),1600,1200,281.25,-12557,-292.53,22988,15,2,1,17.3,-113,11.6,-105.4,5}; -- Thorin's Hall basement
	tmpMapInfo[48]={48,186,tonumber(0x410d81c3),1600,1200,1,0,1,0,1,2,1,0,0,0,0,4}; -- Delving of Fror
	tmpMapInfo[49]={49,187,tonumber(0x41005c2f),800,600,1,0,1,0,5,3,1,0,0,0,0,4}; -- Breeland Brigand Cave
	tmpMapInfo[50]={50,188,tonumber(0x41007dc5),800,600,1,0,1,0,15,3,1,0,0,0,0,5}; -- Rockbelly Pit
	tmpMapInfo[51]={51,189,tonumber(0x41007dbe),800,600,1,0,1,0,6,3,1,0,0,0,0,5}; -- Sprigley's Cellar
	tmpMapInfo[52]={52,190,tonumber(0x41005C0D),800,600,1,0,1,0,15,3,1,0,0,0,0,5}; -- Mirkstone Tunnels
	tmpMapInfo[53]={53,191,tonumber(0x41005C1F),800,600,1,0,1,0,15,3,1,0,0,0,0,5}; -- Silver Deep
	tmpMapInfo[54]={54,192,tonumber(0x41005C2D),1600,1200,1,0,1,0,15,3,1,0,0,0,0,5}; -- Skorgrim's Tomb
	tmpMapInfo[55]={55,193,tonumber(0x41110D27),800,600,1,0,1,0,19,3,1,0,0,0,0,4}; -- Annuminas: Haudh Valandur
	tmpMapInfo[56]={56,194,tonumber(0x41110D29),800,600,1,0,1,0,19,3,1,0,0,0,0,4}; -- Annuminas: Haudh Erendur
	tmpMapInfo[57]={57,195,tonumber(0x41110D2C),1600,1200,1,0,1,0,19,3,1,0,0,0,0,4}; -- Annuminas: Haudh Eldacar
	tmpMapInfo[58]={58,196,tonumber(0x41110D2E),1600,1200,1,0,1,0,19,3,1,0,0,0,0,4}; -- Annuminas: Haudh Arantar
	tmpMapInfo[59]={59,197,tonumber(0x4101fd4f),800,600,1,0,1,0,19,3,1,0,0,0,0,4}; -- Evendim: Gwindethrond


	if tmpAnnotations==nil then tmpAnnotations={} end

	local tmpIndex;
	local tmpElem;
	if iconInfo==nil then iconInfo={} end
	-- remove all of the prior iconInfo records and load the tmpIconInfo records
	while #iconInfo>0 do
		table.remove(iconInfo,1);
	end
	for tmpIndex=1,#tmpIconInfo do
		iconInfo[#iconInfo+1]={tmpIconInfo[tmpIndex][1],tmpIconInfo[tmpIndex][2],tmpIconInfo[tmpIndex][3],tmpIconInfo[tmpIndex][4],tmpIconInfo[tmpIndex][5],tmpIconInfo[tmpIndex][6]};
	end

	if mapInfo==nil then mapInfo={} end
	while #mapInfo>0 do
		table.remove(mapInfo,1);
	end
	for tmpIndex=1,#tmpMapInfo do
		mapInfo[tmpIndex]={};
		for tmpElem=1,#tmpMapInfo[tmpIndex] do
			mapInfo[tmpIndex][tmpElem]=tmpMapInfo[tmpIndex][tmpElem];
		end
	end

	PatchDataSave( Turbine.DataScope.Account, "MM_IconInfo", iconInfo);
	PatchDataSave( Turbine.DataScope.Account, "MM_MapInfo", mapInfo);
end

function ProcessMap(tmpWorld)
	local result,error;
	local success,retval;
	if statusWindow.MapIndex==1 then
		-- handle server specific versions of the Ettenmoors
		if tmpWorld~=nil then
			result,error=loadstring("import \"GaranStuff.MoorMap.Data.MapData_1_"..tmpWorld.."\"");
		else
			result,error=loadstring("import \"GaranStuff.MoorMap.Data.MapData_1\"");
		end
	else
		result,error=loadstring("import \"GaranStuff.MoorMap.Data.MapData_"..statusWindow.MapIndex.."\"");
	end
	if result==nil then
		Turbine.Shell.WriteLine("Error:"..tostring(error));
	else
		-- we may not have a data file for all maps (some have not annotations)
		success,retval=pcall(result);
		if success then
			return retval;
		else
			Turbine.Shell.WriteLine("Error:"..tostring(retval))
			return nil;
		end
	end
end

LoadDefaults(); -- need to have the mapInfo loaded before we instantiate the display
statusWindow=StatusDisplay();
statusWindow:SetZOrder(statusWindow:GetZOrder()+1);
statusWindow:SetVisible(true);